[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --everything-is-local
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


* * *
The entire **[Pro Git book](https://git-scm.com/book)** written by Scott Chacon and Ben Straub is available to [read online for free](https://git-scm.com/book). Dead tree versions are available on [Amazon.com](https://www.amazon.com/Pro-Git-Scott-Chacon/dp/1484200772?ie=UTF8&camp=1789&creative=9325&creativeASIN=1430218339&linkCode=as2&tag=git-sfconservancy-20).
# Videos
  * [![](https://git-scm.com/images/video/ep2@2x.png)](https://git-scm.com/video/what-is-git)
####  [What is Git?](https://git-scm.com/video/what-is-git)
**Length:** 08:15
  * [![](https://git-scm.com/images/video/ep4@2x.png)](https://git-scm.com/video/quick-wins)
####  [Quick Wins with Git](https://git-scm.com/video/quick-wins)
**Length:** 05:06


  * [![](https://git-scm.com/images/video/ep1@2x.png)](https://git-scm.com/video/what-is-version-control)
####  [What is Version Control?](https://git-scm.com/video/what-is-version-control)
**Length:** 05:59
  * [![](https://git-scm.com/images/video/ep3@2x.png)](https://git-scm.com/video/get-going)
####  [Get Going with Git](https://git-scm.com/video/get-going)
**Length:** 04:26


[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
